@@ -1,5 +1,5 @@
 # Standard Library
-from typing import Any, Dict
+from typing import Any, Dict, List, Union
 
 # Django
 from django.template.loader import render_to_string
@@ -10,7 +10,7 @@ from .renderers import render_turbo_frame, render_turbo_stream
 
 
 def render_turbo_stream_template(
-    template: str,
+    template: Union[str, List[str]],
     context: Dict[str, Any],
     *,
     action: Action,
@@ -41,7 +41,7 @@ def render_turbo_stream_template(
 
 
 def render_turbo_frame_template(
-    template: str, context: Dict[str, Any], *, dom_id: str, **kwargs
+    template: Union[str, List[str]], context: Dict[str, Any], *, dom_id: str, **kwargs
 ) -> str:
     """Renders a *<turbo-frame>* template.
 
